@@ -21,7 +21,7 @@ class BasePackageData:
     LIBRARY_NAME: str = "boto3"
     SERVICE_PREFIX: str = "mypy_boto3"
     SERVICE_PYPI_PREFIX: str = "mypy-boto3"
-    LOCAL_DOC_LINK: str = "https://vemel.github.io/boto3_stubs_docs/"
+    LOCAL_DOC_LINK: str = "https://youtype.github.io/boto3_stubs_docs/"
     IS_ASYNC = False
 
     @classmethod
@@ -81,7 +81,7 @@ class TypesAioBotocorePackageData(BasePackageData):
     LIBRARY_NAME = "aiobotocore"
     SERVICE_PREFIX = "types_aiobotocore"
     SERVICE_PYPI_PREFIX = "types-aiobotocore"
-    LOCAL_DOC_LINK = "https://vemel.github.io/types_aiobotocore_docs/"
+    LOCAL_DOC_LINK = "https://youtype.github.io/types_aiobotocore_docs/"
     IS_ASYNC = True
 
     @staticmethod
@@ -110,7 +110,7 @@ class Boto3StubsPackageData(BasePackageData):
     PYPI_NAME = "boto3-stubs"
     PYPI_LITE_NAME = "boto3-stubs-lite"
     LIBRARY_NAME = "boto3"
-    LOCAL_DOC_LINK = "https://vemel.github.io/boto3_stubs_docs/"
+    LOCAL_DOC_LINK = "https://youtype.github.io/boto3_stubs_docs/"
 
 
 class Boto3StubsLitePackageData(Boto3StubsPackageData):
