@@ -31,7 +31,7 @@ class ServicePackage(Package):
         self,
         data: type[BasePackageData],
         service_name: ServiceName,
-        client: Client,
+        client: Client | None = None,
         service_resource: ServiceResource | None = None,
         waiters: Iterable[Waiter] = tuple(),
         paginators: Iterable[Paginator] = tuple(),
@@ -43,7 +43,7 @@ class ServicePackage(Package):
         self.name = data.get_service_package_name(service_name)
         self.pypi_name = data.get_service_pypi_name(service_name)
         self.service_name = service_name
-        self.client = client
+        self._client = client
         self.service_resource = service_resource
         self.waiters = list(waiters)
         self.paginators = list(paginators)
@@ -51,6 +51,15 @@ class ServicePackage(Package):
         self.literals = list(literals)
         self.helper_functions = list(helper_functions)
 
+    @property
+    def client(self) -> Client:
+        """
+        Service Client.
+        """
+        if not self._client:
+            raise ValueError(f"Client is not present for {self.service_name}")
+        return self._client
+
     def extract_literals(self) -> list[TypeLiteral]:
         """
         Extract literals from children.
